@@ -10,6 +10,9 @@ pub use snakecase_to_camelcase::SnakecaseToCamelcase;
 mod escape_rust_keyword;
 pub use escape_rust_keyword::EscapeRustKeyword;
 
+mod escape_c_keyword;
+pub use escape_c_keyword::EscapeCKeyword;
+
 pub fn invalid_input<S>(cause: S) -> liquid_core::Error
 where
     S: Into<liquid_core::model::KString>,
@@ -23,5 +26,6 @@ pub(crate) fn all() -> Vec<Box<dyn liquid_core::parser::ParseFilter>> {
         crate::filters::CamelcaseToSnakecase.into(),
         crate::filters::SnakecaseToCamelcase.into(),
         crate::filters::EscapeRustKeyword.into(),
+        crate::filters::EscapeCKeyword.into(),
     ]
 }
