@@ -6,7 +6,7 @@ use liquid_core::{Value, ValueView};
 #[derive(Clone, ParseFilter, FilterReflection)]
 #[filter(
     name = "snakecase_to_camelcase",
-    description = "Renders comment with prefix/offset params.",
+    description = "Converts snake_case to CamelCase.",
     parsed(SnakecaseToCamelcaseFilter)
 )]
 pub struct SnakecaseToCamelcase;
